# linkedlabs
This project is created as a Generic solution to find most similar rows(or customers) in a given dataset using DNA matching Algorithms and Artificial Intelligence.

# Installation
Run the following to install:

```python
pip install linkedlabs
```

## Usage

```python
import linkedlabs

# Generate "Hello, World!"
linkedlabs.say_hello()

# Generate "Hello, Everybody!"
linkedlabs.say_hello("Everybody")
```